from setuptools import setup
setup(
    name="barre",
    version="1.0.10",
    py_modules=["barre"],
    description="Minimal progress bar",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    author="Fonk",
    author_email="feelthefonk@gmail.com",
    url="https://github.com/FeelTheFonk/barre",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Logging",
    ],
    python_requires=">=3.8",
)